@@ -3,8 +3,8 @@ import glob
 import os
 import re
 
-from exceptions import (
-    DuplicateJSONFile, InvalidParameter, ExistingEnvironmentVariable)
+from exceptions import (MalformedJSONFile, DuplicateJSONFile,
+                        InvalidParameter, ExistingEnvironmentVariable)
 
 
 class ConfigurationPanda(object):
@@ -91,7 +91,7 @@ class ConfigurationPanda(object):
                 self.__setattr__(
                     attribute_name, json.load(configuration_file))
             except ValueError:
-                raise ValueError(
+                raise MalformedJSONFile(
                     "The configuration file, {}, contains JSON "
                     "syntax errors.".format(configuration_file))
 
